@@ -1,4 +1,6 @@
 import requests
+
+
 class requests_session:
     def __init__(self, optional_func=None, header=None):
         self.ses = requests.Session()
@@ -10,7 +12,9 @@ class requests_session:
             headers = self.const_head
 
         response = self.ses.get(url, headers=headers)
-        if not self.function is None:
+        if self.function is None:
+            pass
+        else:
             self.function(response)
 
         return response
@@ -28,20 +32,19 @@ class requests_session:
     def session(self):
         return self.ses
 
-
     def request(self, method, url, params=None, data=None, headers=None,
-            cookies=None, files=None, auth=None, timeout=None,
-            allow_redirects=True, proxies=None,
-            hooks=None,verify=None,
-            json=None):
+                cookies=None, files=None, auth=None, timeout=None,
+                allow_redirects=True, proxies=None,
+                hooks=None, verify=None,
+                json=None):
 
         if headers is None:
             headers = self.const_head
 
-        request = self.ses.request(url=url,method=method, proxies=proxies,
-                                params=params, data=data, headers=headers,
-                                cookies=cookies, files=files, auth=auth, timeout=timeout,
-                                allow_redirects=allow_redirects, hooks=hooks, verify=verify, json=json)
+        request = self.ses.request(url=url, method=method, proxies=proxies,
+                                   params=params, data=data, headers=headers,
+                                   cookies=cookies, files=files, auth=auth, timeout=timeout,
+                                   allow_redirects=allow_redirects, hooks=hooks, verify=verify, json=json)
 
         if self.function is not None:
             self.function(request)
@@ -56,4 +59,4 @@ class requests_session:
 
 
 def waste():
-    pass
\ No newline at end of file
+    pass
