@@ -1,14 +1,17 @@
 import os
+import random
 import shutil
 import subprocess
 from utils import exceptions
 
+
 def __command(args: list):
     sub = subprocess.Popen(args, stdout=subprocess.DEVNULL, stderr=subprocess.STDOUT)
     sub.wait()
     sub.kill()
     sub.terminate()
 
+
 def _decoder(string_path: str) -> str:
     if string_path.startswith('~'):
         string_path = join(os.path.expanduser('~'), string_path.split('~', 1)[1])
@@ -145,8 +148,6 @@ class Path:
             except AttributeError or Exception:
                 path = path[:-1]
 
-
-
         self.path = path
 
     def append(self, path2):
@@ -167,7 +168,6 @@ class Path:
         with open(self.path, OpenMode) as file:
             file.write(WritingData)
 
-
     def read_file(self, OpenMode):
         with open(self.path, OpenMode) as file:
             file_read = file.read()
@@ -213,6 +213,17 @@ class Path:
             raise FileNotFoundError(self.path)
 
 
+class container:
+    def __init__(self):
+        self.file = Path(join(os.getcwd(), random.random().__str__()))
+
+    def __enter__(self):
+        os.mkdir(abs(self.file))
+        return self.file
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        remove(self.file)
+
 
 # Depreciated Functions
 def remove_file(file, blank):
